@@ -16,17 +16,17 @@
 """The hosts admin extension."""
 
 import webob.exc
-from xml.dom import minidom
 from xml.parsers import expat
 
+from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.api.openstack import xmlutil
-from nova.api.openstack import extensions
 from nova.compute import api as compute_api
 from nova import db
 from nova import exception
 from nova import flags
-from nova import log as logging
+from nova.openstack.common import log as logging
+from nova import utils
 
 
 LOG = logging.getLogger(__name__)
@@ -80,7 +80,7 @@ class HostShowTemplate(xmlutil.TemplateBuilder):
 class HostDeserializer(wsgi.XMLDeserializer):
     def default(self, string):
         try:
-            node = minidom.parseString(string)
+            node = utils.safe_minidom_parse_string(string)
         except expat.ExpatError:
             msg = _("cannot understand XML")
             raise exception.MalformedRequestBody(reason=msg)
@@ -98,6 +98,7 @@ def _list_hosts(req, service=None):
     """
     context = req.environ['nova.context']
     services = db.service_get_all(context, False)
+
     hosts = []
     for host in services:
         hosts.append({"host_name": host['host'], 'service': host['topic']})
@@ -115,7 +116,8 @@ def check_host(fn):
         if id in hosts:
             return fn(self, req, id, *args, **kwargs)
         else:
-            raise exception.HostNotFound(host=id)
+            message = _("Host '%s' could not be found.") % id
+            raise webob.exc.HTTPNotFound(explanation=message)
     return wrapped
 
 
@@ -226,8 +228,6 @@ class HostController(object):
         """
         host = id
         context = req.environ['nova.context']
-        # Expected to use AuthMiddleware.
-        # Otherwise, non-admin user can use describe-resource
         if not context.is_admin:
             msg = _("Describe-resource is admin only functionality")
             raise webob.exc.HTTPForbidden(explanation=msg)
@@ -273,7 +273,7 @@ class HostController(object):
             vcpus = [i['vcpus'] for i in instance_refs
                      if i['project_id'] == project_id]
 
-            mem = [i['memory_mb']  for i in instance_refs
+            mem = [i['memory_mb'] for i in instance_refs
                    if i['project_id'] == project_id]
 
             disk = [i['root_gb'] + i['ephemeral_gb'] for i in instance_refs
