@@ -23,7 +23,7 @@ from nova.api.openstack import wsgi
 from nova import compute
 from nova import exception
 from nova import flags
-from nova import log as logging
+from nova.openstack.common import log as logging
 from nova import utils
 
 
