@@ -16,8 +16,6 @@
 
 """The security groups extension."""
 
-from xml.dom import minidom
-
 import webob
 from webob import exc
 
@@ -30,6 +28,7 @@ from nova import db
 from nova import exception
 from nova import flags
 from nova.openstack.common import log as logging
+from nova import utils
 
 
 LOG = logging.getLogger(__name__)
@@ -110,7 +109,7 @@ class SecurityGroupXMLDeserializer(wsgi.MetadataXMLDeserializer):
     """
     def default(self, string):
         """Deserialize an xml-formatted security group create request"""
-        dom = minidom.parseString(string)
+        dom = utils.safe_minidom_parse_string(string)
         security_group = {}
         sg_node = self.find_first_child_named(dom,
                                                'security_group')
@@ -131,7 +130,7 @@ class SecurityGroupRulesXMLDeserializer(wsgi.MetadataXMLDeserializer):
 
     def default(self, string):
         """Deserialize an xml-formatted security group create request"""
-        dom = minidom.parseString(string)
+        dom = utils.safe_minidom_parse_string(string)
         security_group_rule = self._extract_security_group_rule(dom)
         return {'body': {'security_group_rule': security_group_rule}}
 
@@ -389,7 +388,7 @@ class ServerSecurityGroupController(SecurityGroupControllerBase):
         try:
             instance = self.compute_api.get(context, server_id)
         except exception.InstanceNotFound as exp:
-            raise exc.HTTPNotFound(explanation=unicode(exp))
+            raise exc.HTTPNotFound(explanation=exp.format_message())
 
         groups = db.security_group_get_by_instance(context, instance['id'])
 
@@ -430,11 +429,11 @@ class SecurityGroupActionController(wsgi.Controller):
             instance = self.compute_api.get(context, id)
             method(context, instance, group_name)
         except exception.SecurityGroupNotFound as exp:
-            raise exc.HTTPNotFound(explanation=unicode(exp))
+            raise exc.HTTPNotFound(explanation=exp.format_message())
         except exception.InstanceNotFound as exp:
-            raise exc.HTTPNotFound(explanation=unicode(exp))
+            raise exc.HTTPNotFound(explanation=exp.format_message())
         except exception.Invalid as exp:
-            raise exc.HTTPBadRequest(explanation=unicode(exp))
+            raise exc.HTTPBadRequest(explanation=exp.format_message())
 
         return webob.Response(status_int=202)
 
