@@ -1,4 +1,4 @@
-# Copyright 2011 OpenStack Foundation
+# Copyright 2011 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,18 +15,20 @@
 
 import webob.exc
 
-from nova.api.openstack.api_version_request \
-    import MAX_PROXY_API_SUPPORT_VERSION
 from nova.api.openstack import common
-from nova.api.openstack.compute.schemas import images as schema
 from nova.api.openstack.compute.views import images as views_images
 from nova.api.openstack import wsgi
-from nova.api import validation
+from nova.api.openstack import xmlutil
 from nova import exception
-from nova.i18n import _
-from nova.image import glance
+from nova import flags
+import nova.image.glance
+from nova.openstack.common import log as logging
+import nova.utils
 
 
+LOG = logging.getLogger(__name__)
+FLAGS = flags.FLAGS
+
 SUPPORTED_FILTERS = {
     'name': 'name',
     'status': 'status',
@@ -38,17 +40,72 @@ SUPPORTED_FILTERS = {
 }
 
 
-class ImagesController(wsgi.Controller):
+def make_image(elem, detailed=False):
+    elem.set('name')
+    elem.set('id')
+
+    if detailed:
+        elem.set('updated')
+        elem.set('created')
+        elem.set('status')
+        elem.set('progress')
+        elem.set('minRam')
+        elem.set('minDisk')
+
+        server = xmlutil.SubTemplateElement(elem, 'server', selector='server')
+        server.set('id')
+        xmlutil.make_links(server, 'links')
+
+        elem.append(common.MetadataTemplate())
+
+    xmlutil.make_links(elem, 'links')
+
+
+image_nsmap = {None: xmlutil.XMLNS_V11, 'atom': xmlutil.XMLNS_ATOM}
+
+
+class ImageTemplate(xmlutil.TemplateBuilder):
+    def construct(self):
+        root = xmlutil.TemplateElement('image', selector='image')
+        make_image(root, detailed=True)
+        return xmlutil.MasterTemplate(root, 1, nsmap=image_nsmap)
+
+
+class MinimalImagesTemplate(xmlutil.TemplateBuilder):
+    def construct(self):
+        root = xmlutil.TemplateElement('images')
+        elem = xmlutil.SubTemplateElement(root, 'image', selector='images')
+        make_image(elem)
+        xmlutil.make_links(root, 'images_links')
+        return xmlutil.MasterTemplate(root, 1, nsmap=image_nsmap)
+
+
+class ImagesTemplate(xmlutil.TemplateBuilder):
+    def construct(self):
+        root = xmlutil.TemplateElement('images')
+        elem = xmlutil.SubTemplateElement(root, 'image', selector='images')
+        make_image(elem, detailed=True)
+        return xmlutil.MasterTemplate(root, 1, nsmap=image_nsmap)
+
+
+class Controller(wsgi.Controller):
     """Base controller for retrieving/displaying images."""
 
     _view_builder_class = views_images.ViewBuilder
 
-    def __init__(self):
-        super(ImagesController, self).__init__()
-        self._image_api = glance.API()
+    def __init__(self, image_service=None, **kwargs):
+        """Initialize new `ImageController`.
+
+        :param image_service: `nova.image.glance:GlanceImageService`
+
+        """
+        super(Controller, self).__init__(**kwargs)
+        self._image_service = (image_service or
+                               nova.image.glance.get_default_image_service())
 
     def _get_filters(self, req):
-        """Return a dictionary of query param filters from the request.
+        """
+        Return a dictionary of query param filters from the request
 
         :param req: the Request object coming from the wsgi layer
         :retval a dict of key/value filters
@@ -74,9 +131,7 @@ class ImagesController(wsgi.Controller):
 
         return filters
 
-    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
-    @wsgi.expected_errors(404)
-    @validation.query_schema(schema.show_query)
+    @wsgi.serializers(xml=ImageTemplate)
     def show(self, req, id):
         """Return detailed information about a specific image.
 
@@ -86,16 +141,13 @@ class ImagesController(wsgi.Controller):
         context = req.environ['nova.context']
 
         try:
-            image = self._image_api.get(context, id)
-        except (exception.ImageNotFound, exception.InvalidImageRef):
+            image = self._image_service.show(context, id)
+        except (exception.NotFound, exception.InvalidImageRef):
             explanation = _("Image not found.")
             raise webob.exc.HTTPNotFound(explanation=explanation)
 
         return self._view_builder.show(req, image)
 
-    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
-    @wsgi.expected_errors((403, 404))
-    @wsgi.response(204)
     def delete(self, req, id):
         """Delete an image, if allowed.
 
@@ -104,19 +156,13 @@ class ImagesController(wsgi.Controller):
         """
         context = req.environ['nova.context']
         try:
-            self._image_api.delete(context, id)
+            self._image_service.delete(context, id)
         except exception.ImageNotFound:
             explanation = _("Image not found.")
             raise webob.exc.HTTPNotFound(explanation=explanation)
-        except exception.ImageNotAuthorized:
-            # The image service raises this exception on delete if glanceclient
-            # raises HTTPForbidden.
-            explanation = _("You are not allowed to delete the image.")
-            raise webob.exc.HTTPForbidden(explanation=explanation)
+        return webob.exc.HTTPNoContent()
 
-    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
-    @wsgi.expected_errors(400)
-    @validation.query_schema(schema.index_query)
+    @wsgi.serializers(xml=MinimalImagesTemplate)
     def index(self, req):
         """Return an index listing of images available to the request.
 
@@ -125,18 +171,19 @@ class ImagesController(wsgi.Controller):
         """
         context = req.environ['nova.context']
         filters = self._get_filters(req)
+        params = req.GET.copy()
         page_params = common.get_pagination_params(req)
+        for key, val in page_params.iteritems():
+            params[key] = val
 
         try:
-            images = self._image_api.get_all(context, filters=filters,
-                                             **page_params)
+            images = self._image_service.detail(context, filters=filters,
+                                                **page_params)
         except exception.Invalid as e:
-            raise webob.exc.HTTPBadRequest(explanation=e.format_message())
+            raise webob.exc.HTTPBadRequest(explanation=str(e))
         return self._view_builder.index(req, images)
 
-    @wsgi.Controller.api_version("2.1", MAX_PROXY_API_SUPPORT_VERSION)
-    @wsgi.expected_errors(400)
-    @validation.query_schema(schema.detail_query)
+    @wsgi.serializers(xml=ImagesTemplate)
     def detail(self, req):
         """Return a detailed index listing of images available to the request.
 
@@ -145,11 +192,21 @@ class ImagesController(wsgi.Controller):
         """
         context = req.environ['nova.context']
         filters = self._get_filters(req)
+        params = req.GET.copy()
         page_params = common.get_pagination_params(req)
+        for key, val in page_params.iteritems():
+            params[key] = val
         try:
-            images = self._image_api.get_all(context, filters=filters,
-                                             **page_params)
+            images = self._image_service.detail(context, filters=filters,
+                                                **page_params)
         except exception.Invalid as e:
-            raise webob.exc.HTTPBadRequest(explanation=e.format_message())
+            raise webob.exc.HTTPBadRequest(explanation=str(e))
 
         return self._view_builder.detail(req, images)
+
+    def create(self, *args, **kwargs):
+        raise webob.exc.HTTPMethodNotAllowed()
+
+
+def create_resource():
+    return wsgi.Resource(Controller())
