@@ -22,8 +22,8 @@ from nova.api.openstack import common
 from nova.api.openstack.compute.views import addresses as views_addresses
 from nova.api.openstack.compute.views import flavors as views_flavors
 from nova.api.openstack.compute.views import images as views_images
-from nova import log as logging
-from nova import utils
+from nova.openstack.common import log as logging
+from nova.openstack.common import timeutils
 
 
 LOG = logging.getLogger(__name__)
@@ -66,7 +66,9 @@ class ViewBuilder(common.ViewBuilder):
         return {
             "server": {
                 "id": instance["uuid"],
-                "links": self._get_links(request, instance["uuid"]),
+                "links": self._get_links(request,
+                                         instance["uuid"],
+                                         self._collection_name),
             },
         }
 
@@ -77,7 +79,9 @@ class ViewBuilder(common.ViewBuilder):
             "server": {
                 "id": instance["uuid"],
                 "name": instance["display_name"],
-                "links": self._get_links(request, instance["uuid"]),
+                "links": self._get_links(request,
+                                         instance["uuid"],
+                                         self._collection_name),
             },
         }
 
@@ -95,14 +99,14 @@ class ViewBuilder(common.ViewBuilder):
                 "hostId": self._get_host_id(instance) or "",
                 "image": self._get_image(request, instance),
                 "flavor": self._get_flavor(request, instance),
-                "created": utils.isotime(instance["created_at"]),
-                "updated": utils.isotime(instance["updated_at"]),
+                "created": timeutils.isotime(instance["created_at"]),
+                "updated": timeutils.isotime(instance["updated_at"]),
                 "addresses": self._get_addresses(request, instance),
                 "accessIPv4": instance.get("access_ip_v4") or "",
                 "accessIPv6": instance.get("access_ip_v6") or "",
-                "key_name": instance.get("key_name") or "",
-                "config_drive": instance.get("config_drive"),
-                "links": self._get_links(request, instance["uuid"]),
+                "links": self._get_links(request,
+                                         instance["uuid"],
+                                         self._collection_name),
             },
         }
         _inst_fault = self._get_fault(request, instance)
@@ -125,7 +129,9 @@ class ViewBuilder(common.ViewBuilder):
     def _list_view(self, func, request, servers):
         """Provide a view for a list of servers."""
         server_list = [func(request, server)["server"] for server in servers]
-        servers_links = self._get_collection_links(request, servers)
+        servers_links = self._get_collection_links(request,
+                                                   servers,
+                                                   self._collection_name)
         servers_dict = dict(servers=server_list)
 
         if servers_links:
@@ -159,7 +165,9 @@ class ViewBuilder(common.ViewBuilder):
     def _get_image(self, request, instance):
         image_ref = instance["image_ref"]
         image_id = str(common.get_id_from_href(image_ref))
-        bookmark = self._image_builder._get_bookmark_link(request, image_id)
+        bookmark = self._image_builder._get_bookmark_link(request,
+                                                          image_id,
+                                                          "images")
         return {
             "id": image_id,
             "links": [{
@@ -169,12 +177,17 @@ class ViewBuilder(common.ViewBuilder):
         }
 
     def _get_flavor(self, request, instance):
-        flavor_id = instance["instance_type"]["flavorid"]
-        flavor_ref = self._flavor_builder._get_href_link(request, flavor_id)
+        instance_type = instance["instance_type"]
+        if not instance_type:
+            LOG.warn(_("Instance has had its instance_type removed "
+                    "from the DB"), instance=instance)
+            return {}
+        flavor_id = instance_type["flavorid"]
         flavor_bookmark = self._flavor_builder._get_bookmark_link(request,
-                                                                  flavor_id)
+                                                                  flavor_id,
+                                                                  "flavors")
         return {
-            "id": str(common.get_id_from_href(flavor_ref)),
+            "id": str(flavor_id),
             "links": [{
                 "rel": "bookmark",
                 "href": flavor_bookmark,
@@ -189,7 +202,7 @@ class ViewBuilder(common.ViewBuilder):
 
         fault_dict = {
             "code": fault["code"],
-            "created": utils.isotime(fault["created_at"]),
+            "created": timeutils.isotime(fault["created_at"]),
             "message": fault["message"],
         }
 
