@@ -1,4 +1,6 @@
-# Copyright 2011 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2011 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,21 +15,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import re
-
-from oslo_log import log as logging
 import paste.urlmap
-import six
+import re
+import urllib2
 
 from nova.api.openstack import wsgi
-
-if six.PY2:
-    import urllib2
-else:
-    from urllib import request as urllib2
-
-
-LOG = logging.getLogger(__name__)
+from nova.openstack.common import log as logging
 
 
 _quoted_string_re = r'"[^"\\]*(?:\\.[^"\\]*)*"'
@@ -35,6 +28,8 @@ _option_header_piece_re = re.compile(r';\s*([^\s;=]+|%s)\s*'
                                      r'(?:=\s*([^;]+|%s))?\s*' %
     (_quoted_string_re, _quoted_string_re))
 
+LOG = logging.getLogger(__name__)
+
 
 def unquote_header_value(value):
     """Unquotes a header value.
@@ -98,7 +93,7 @@ def parse_options_header(value):
         return '', {}
 
     parts = _tokenize(';' + value)
-    name = next(parts)[0]
+    name = parts.next()[0]
     extra = dict(parts)
     return name, extra
 
@@ -137,6 +132,14 @@ class Accept(object):
 
         return best_content_type, best_params
 
+    def content_type_params(self, best_content_type):
+        """Find parameters in Accept header for given content type."""
+        for content_type, params in self._content_types:
+            if best_content_type == content_type:
+                return params
+
+        return {}
+
     def _match_mask(self, mask, content_type):
         if '*' not in mask:
             return content_type == mask
@@ -168,27 +171,8 @@ class URLMap(paste.urlmap.URLMap):
         for (domain, app_url), app in self.applications:
             if domain and domain != host and domain != host + ':' + port:
                 continue
-            # Rudimentary "wildcard" support:
-            # By declaring a urlmap path ending in '/+', you're saying the
-            # incoming path must start with everything up to and including the
-            # '/' *and* have something after that as well. For example, path
-            # /foo/bar/+ will match /foo/bar/baz, but not /foo/bar/ or /foo/bar
-            # NOTE(efried): This assumes we'll never need a path URI component
-            #               that legitimately starts with '+'. (We could use a
-            #               more obscure character/sequence here in that case.)
-            if app_url.endswith('/+'):
-                # Must be requesting at least the path element (including /)
-                if not path_info.startswith(app_url[:-1]):
-                    continue
-                # ...but also must be requesting something after that /
-                if len(path_info) < len(app_url):
-                    continue
-                # Trim the /+ off the app_url to make it look "normal" for e.g.
-                # proper splitting of SCRIPT_NAME and PATH_INFO.
-                return app, app_url[:-2]
-            # Normal (non-wildcarded) prefix match
-            if (path_info == app_url or
-                    path_info.startswith(app_url + '/')):
+            if (path_info == app_url
+                or path_info.startswith(app_url + '/')):
                 return app, app_url
 
         return None, None
@@ -215,7 +199,7 @@ class URLMap(paste.urlmap.URLMap):
         parts = path_info.rsplit('.', 1)
         if len(parts) > 1:
             possible_type = 'application/' + parts[1]
-            if possible_type in wsgi.get_supported_content_types():
+            if possible_type in wsgi.SUPPORTED_CONTENT_TYPES:
                 mime_type = possible_type
 
         parts = path_info.split('/')
@@ -276,7 +260,7 @@ class URLMap(paste.urlmap.URLMap):
         # 2) Content-Type header (eg application/json;version=1.1)
         # 3) Accept header (eg application/json;q=0.8;version=1.1)
 
-        supported_content_types = list(wsgi.get_supported_content_types())
+        supported_content_types = list(wsgi.SUPPORTED_CONTENT_TYPES)
 
         mime_type, app, app_url = self._path_strategy(host, port, path_info)
 
@@ -309,6 +293,5 @@ class URLMap(paste.urlmap.URLMap):
             environ['nova.best_content_type'] = mime_type
             return app(environ, start_response)
 
-        LOG.debug('Could not find application for %s', environ['PATH_INFO'])
         environ['paste.urlmap_object'] = self
         return self.not_found_application(environ, start_response)
