@@ -1,4 +1,7 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2011 Cloudscaling, Inc.
+# Author: Matthew Hooker <matt@cloudscaling.com>
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,19 +17,32 @@
 #    under the License.
 
 import base64
-
-from oslo_log import log as logging
-import rfc3986
-import six
-
+import logging
+import re
+import socket
 
 LOG = logging.getLogger(__name__)
 
 
+def _get_path_validator_regex():
+    # rfc3986 path validator regex from
+    # http://jmrware.com/articles/2009/uri_regexp/URI_regex.html
+    pchar = "([A-Za-z0-9\-._~!$&'()*+,;=:@]|%[0-9A-Fa-f]{2})"
+    path = "((/{pchar}*)*|"
+    path += "/({pchar}+(/{pchar}*)*)?|"
+    path += "{pchar}+(/{pchar}*)*|"
+    path += "{pchar}+(/{pchar}*)*|)"
+    path = path.format(pchar=pchar)
+    return re.compile(path)
+
+
+VALIDATE_PATH_RE = _get_path_validator_regex()
+
+
 def validate_str(max_length=None):
 
     def _do(val):
-        if not isinstance(val, six.string_types):
+        if not isinstance(val, basestring):
             return False
         if max_length and len(val) > max_length:
             return False
@@ -53,9 +69,7 @@ def validate_url_path(val):
     if not validate_str()(val):
         return False
 
-    uri = rfc3986.URIReference(None, None, val, None, None)
-
-    return uri.path_is_valid() and val.startswith('/')
+    return VALIDATE_PATH_RE.match(val).end() == len(val)
 
 
 def validate_image_path(val):
@@ -70,7 +84,7 @@ def validate_image_path(val):
     if val[0] == '/':
         return False
 
-    # make sure the image path is rfc3986 compliant
+    # make sure the image path if rfc3986 compliant
     # prepend '/' to make input validate
     if not validate_url_path('/' + val):
         return False
@@ -78,10 +92,18 @@ def validate_image_path(val):
     return True
 
 
-def validate_user_data(user_data):
-    """Check if the user_data is encoded properly."""
+def validate_ipv4(addr):
     try:
-        base64.b64decode(user_data)
+        socket.inet_aton(addr)
+    except (socket.error, TypeError):
+        return False
+    return True
+
+
+def validate_user_data(user_data):
+    """Check if the user_data is encoded properly"""
+    try:
+        user_data = base64.b64decode(user_data)
     except TypeError:
         return False
     return True
@@ -113,8 +135,8 @@ def validate(args, validator):
         assert callable(f)
 
         if not f(args[key]):
-            LOG.debug("%(key)s with value %(value)s failed"
-                      " validator %(name)s",
+            LOG.debug(_("%(key)s with value %(value)s failed"
+                        " validator %(name)s"),
                       {'key': key, 'value': args[key], 'name': f.__name__})
             return False
     return True
