@@ -24,7 +24,8 @@ library to work with nova.
 """
 
 import fnmatch
-import json
+
+from nova.openstack.common import jsonutils
 
 
 class Store(object):
@@ -114,7 +115,7 @@ def _match_query(query, attrs):
     """Match an ldap query to an attribute dictionary.
 
     The characters &, |, and ! are supported in the query. No syntax checking
-    is performed, so malformed querys will not work correctly.
+    is performed, so malformed queries will not work correctly.
     """
     # cut off the parentheses
     inner = query[1:-1]
@@ -171,7 +172,7 @@ def _match(key, value, attrs):
 def _subs(value):
     """Returns a list of subclass strings.
 
-    The strings represent the ldap objectclass plus any subclasses that
+    The strings represent the ldap object class plus any subclasses that
     inherit from it. Fakeldap doesn't know about the ldap object structure,
     so subclasses need to be defined manually in the dictionary below.
 
@@ -191,7 +192,7 @@ def _from_json(encoded):
     Returns a list of strings
 
     """
-    return [str(x) for x in json.loads(encoded)]
+    return [str(x) for x in jsonutils.loads(encoded)]
 
 
 def _to_json(unencoded):
@@ -204,7 +205,7 @@ def _to_json(unencoded):
     Returns a json string
 
     """
-    return json.dumps(list(unencoded))
+    return jsonutils.dumps(list(unencoded))
 
 
 server_fail = False
@@ -244,9 +245,9 @@ class FakeLDAP(object):
     def modify_s(self, dn, attrs):
         """Modify the object at dn using the attribute list.
 
-        Args:
-        dn -- a dn
-        attrs -- a list of tuples in the following form:
+        :param dn: a dn
+        :param attrs: a list of tuples in the following form::
+
             ([MOD_ADD | MOD_DELETE | MOD_REPACE], attribute, value)
 
         """
@@ -266,6 +267,20 @@ class FakeLDAP(object):
                 values.remove(v)
             values = store.hset(key, k, _to_json(values))
 
+    def modrdn_s(self, dn, newrdn):
+        oldobj = self.search_s(dn, SCOPE_BASE)
+        if not oldobj:
+            raise NO_SUCH_OBJECT()
+        newdn = "%s,%s" % (newrdn, dn.partition(',')[2])
+        newattrs = oldobj[0][1]
+
+        modlist = []
+        for attrtype in newattrs.keys():
+            modlist.append((attrtype, newattrs[attrtype]))
+
+        self.add_s(newdn, modlist)
+        self.delete_s(dn)
+
     def search_s(self, dn, scope, query=None, fields=None):
         """Search for all matching objects under dn using the query.
 
@@ -283,10 +298,14 @@ class FakeLDAP(object):
             raise NotImplementedError(str(scope))
         store = Store.instance()
         if scope == SCOPE_BASE:
-            keys = ["%s%s" % (self.__prefix, dn)]
+            pattern = "%s%s" % (self.__prefix, dn)
+            keys = store.keys(pattern)
         else:
             keys = store.keys("%s*%s" % (self.__prefix, dn))
 
+        if not keys:
+            raise NO_SUCH_OBJECT()
+
         objects = []
         for key in keys:
             # get the attributes from the store
@@ -301,9 +320,6 @@ class FakeLDAP(object):
                 attrs = dict([(k, v) for k, v in attrs.iteritems()
                               if not fields or k in fields])
                 objects.append((key[len(self.__prefix):], attrs))
-            # pylint: enable=E1103
-        if objects == []:
-            raise NO_SUCH_OBJECT()
         return objects
 
     @property
