@@ -25,35 +25,74 @@ necessary.
 
 """
 
+# possible task states during create()
 SCHEDULING = 'scheduling'
 BLOCK_DEVICE_MAPPING = 'block_device_mapping'
 NETWORKING = 'networking'
 SPAWNING = 'spawning'
 
+# possible task states during snapshot()
 IMAGE_SNAPSHOT = 'image_snapshot'
+
+# possible task states during backup()
 IMAGE_BACKUP = 'image_backup'
 
+# possible task states during set_admin_password()
 UPDATING_PASSWORD = 'updating_password'
 
+# possible task states during resize()
 RESIZE_PREP = 'resize_prep'
 RESIZE_MIGRATING = 'resize_migrating'
 RESIZE_MIGRATED = 'resize_migrated'
 RESIZE_FINISH = 'resize_finish'
+
+# possible task states during revert_resize()
 RESIZE_REVERTING = 'resize_reverting'
+
+# possible task states during confirm_resize()
 RESIZE_CONFIRMING = 'resize_confirming'
-RESIZE_VERIFY = 'resize_verify'
-
-REBUILDING = 'rebuilding'
 
+# possible task states during reboot()
 REBOOTING = 'rebooting'
+REBOOTING_HARD = 'rebooting_hard'
+
+# possible task states during pause()
 PAUSING = 'pausing'
+
+# possible task states during unpause()
 UNPAUSING = 'unpausing'
+
+# possible task states during suspend()
 SUSPENDING = 'suspending'
+
+# possible task states during resume()
 RESUMING = 'resuming'
 
+# possible task states during stop()
+STOPPING = 'stopping'
+
+# possible task states during start()
+STARTING = 'starting'
+
+# possible task states during soft_delete()
+POWERING_OFF = 'powering-off'
+
+# possible task states during restore()
+POWERING_ON = 'powering-on'
+
+# possible task states during rescue()
 RESCUING = 'rescuing'
+
+# possible task states during unrescue()
 UNRESCUING = 'unrescuing'
 
+# possible task states during rebuild()
+REBUILDING = 'rebuilding'
+REBUILD_BLOCK_DEVICE_MAPPING = "rebuild_block_device_mapping"
+REBUILD_SPAWNING = 'rebuild_spawning'
+
+# possible task states during live_migrate()
+MIGRATING = "migrating"
+
+# possible task states during delete()
 DELETING = 'deleting'
-STOPPING = 'stopping'
-STARTING = 'starting'
