@@ -18,17 +18,14 @@
 
 """Database setup and migration commands."""
 
-from nova import flags
 from nova import utils
 
 
-FLAGS = flags.FLAGS
-flags.DECLARE('db_backend', 'nova.db.api')
-
-
-IMPL = utils.LazyPluggable(FLAGS['db_backend'],
+IMPL = utils.LazyPluggable('db_backend',
                            sqlalchemy='nova.db.sqlalchemy.migration')
 
+INIT_VERSION = 81
+
 
 def db_sync(version=None):
     """Migrate the database to `version` or the most recent version."""
