@@ -1,4 +1,6 @@
-# Copyright (c) 2011 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright (c) 2011 OpenStack, LLC.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,23 +14,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-from stevedore import driver
+from nova import flags
+from nova.openstack.common import cfg
+from nova import utils
 
 
 ipv6_backend_opt = cfg.StrOpt('ipv6_backend',
                               default='rfc2462',
                               help='Backend to use for IPv6 generation')
 
-CONF = cfg.CONF
-CONF.register_opt(ipv6_backend_opt)
+FLAGS = flags.FLAGS
+FLAGS.register_opt(ipv6_backend_opt)
 IMPL = None
 
 
 def reset_backend():
     global IMPL
-    IMPL = driver.DriverManager("nova.ipv6_backend",
-                                CONF.ipv6_backend).driver
+    IMPL = utils.LazyPluggable('ipv6_backend',
+               rfc2462='nova.ipv6.rfc2462',
+               account_identifier='nova.ipv6.account_identifier')
 
 
 def to_global(prefix, mac, project_id):
