@@ -16,4 +16,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from nova.network.api import API
+# Importing full names to not pollute the namespace and cause possible
+# collisions with use of 'from nova.network import <foo>' elsewhere.
+import nova.flags
+import nova.openstack.common.importutils
+
+
+def API():
+    importutils = nova.openstack.common.importutils
+    cls = importutils.import_class(nova.flags.FLAGS.network_api_class)
+    return cls()
