@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 Nicira Networks, Inc
 # All Rights Reserved.
 #
@@ -13,52 +15,49 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-
+from nova import flags
 from nova.network import linux_net
-import nova.privsep.linux_net
+from nova.openstack.common import log as logging
 from nova import utils
 
 LOG = logging.getLogger(__name__)
 
+FLAGS = flags.FLAGS
+
 
 class L3Driver(object):
-    """Abstract class that defines a generic L3 API."""
+    """Abstract class that defines a generic L3 API"""
 
     def __init__(self, l3_lib=None):
         raise NotImplementedError()
 
     def initialize(self, **kwargs):
-        """Set up basic L3 networking functionality."""
+        """Set up basic L3 networking functionality"""
         raise NotImplementedError()
 
-    def initialize_network(self, cidr, is_external):
-        """Enable rules for a specific network."""
+    def initialize_network(self, network):
+        """Enable rules for a specific network"""
         raise NotImplementedError()
 
-    def initialize_gateway(self, network_ref):
-        """Set up a gateway on this network."""
+    def initialize_gateway(self, network):
+        """Set up a gateway on this network"""
         raise NotImplementedError()
 
     def remove_gateway(self, network_ref):
-        """Remove an existing gateway on this network."""
+        """Remove an existing gateway on this network"""
         raise NotImplementedError()
 
     def is_initialized(self):
-        """:returns: True/False (whether the driver is initialized)."""
+        """:returns: True/False (whether the driver is initialized)"""
         raise NotImplementedError()
 
-    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                        network=None):
+    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
         """Add a floating IP bound to the fixed IP with an optional
            l3_interface_id.  Some drivers won't care about the
-           l3_interface_id so just pass None in that case. Network
-           is also an optional parameter.
-        """
+           l3_interface_id so just pass None in that case"""
         raise NotImplementedError()
 
-    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                           network=None):
+    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
         raise NotImplementedError()
 
     def add_vpn(self, public_ip, port, private_ip):
@@ -67,15 +66,12 @@ class L3Driver(object):
     def remove_vpn(self, public_ip, port, private_ip):
         raise NotImplementedError()
 
-    def clean_conntrack(self, fixed_ip):
-        raise NotImplementedError()
-
     def teardown(self):
         raise NotImplementedError()
 
 
 class LinuxNetL3(L3Driver):
-    """L3 driver that uses linux_net as the backend."""
+    """L3 driver that uses linux_net as the backend"""
     def __init__(self):
         self.initialized = False
 
@@ -83,14 +79,7 @@ class LinuxNetL3(L3Driver):
         if self.initialized:
             return
         LOG.debug("Initializing linux_net L3 driver")
-        fixed_range = kwargs.get('fixed_range', False)
-        networks = kwargs.get('networks', None)
-        if not fixed_range and networks is not None:
-            for network in networks:
-                if network['enable_dhcp']:
-                    is_ext = (network['dhcp_server'] is not None and
-                              network['dhcp_server'] != network['gateway'])
-                    self.initialize_network(network['cidr'], is_ext)
+        linux_net.init_host()
         linux_net.ensure_metadata_ip()
         linux_net.metadata_forward()
         self.initialized = True
@@ -98,8 +87,8 @@ class LinuxNetL3(L3Driver):
     def is_initialized(self):
         return self.initialized
 
-    def initialize_network(self, cidr, is_external):
-        linux_net.init_host(cidr, is_external)
+    def initialize_network(self, cidr):
+        linux_net.add_snat_rule(cidr)
 
     def initialize_gateway(self, network_ref):
         mac_address = utils.generate_mac_address()
@@ -110,18 +99,15 @@ class LinuxNetL3(L3Driver):
     def remove_gateway(self, network_ref):
         linux_net.unplug(network_ref)
 
-    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                        network=None):
-        linux_net.ensure_floating_forward(floating_ip, fixed_ip,
-                                          l3_interface_id, network)
+    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
         linux_net.bind_floating_ip(floating_ip, l3_interface_id)
+        linux_net.ensure_floating_forward(floating_ip, fixed_ip,
+                                          l3_interface_id)
 
-    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                           network=None):
-        nova.privsep.linux_net.unbind_ip(l3_interface_id, floating_ip)
+    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
+        linux_net.unbind_floating_ip(floating_ip, l3_interface_id)
         linux_net.remove_floating_forward(floating_ip, fixed_ip,
-                                          l3_interface_id, network)
-        nova.privsep.linux_net.clean_conntrack(fixed_ip)
+                                          l3_interface_id)
 
     def add_vpn(self, public_ip, port, private_ip):
         linux_net.ensure_vpn_forward(public_ip, port, private_ip)
@@ -137,9 +123,8 @@ class LinuxNetL3(L3Driver):
 
 class NullL3(L3Driver):
     """The L3 driver that doesn't do anything.  This class can be used when
-       nova-network should not manipulate L3 forwarding at all (e.g., in a Flat
-       or FlatDHCP scenario).
-    """
+       nova-network shuld not manipulate L3 forwarding at all (e.g., in a Flat
+       or FlatDHCP scenario"""
     def __init__(self):
         pass
 
@@ -149,7 +134,7 @@ class NullL3(L3Driver):
     def is_initialized(self):
         return True
 
-    def initialize_network(self, cidr, is_external):
+    def initialize_network(self, cidr):
         pass
 
     def initialize_gateway(self, network_ref):
@@ -158,12 +143,10 @@ class NullL3(L3Driver):
     def remove_gateway(self, network_ref):
         pass
 
-    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                        network=None):
+    def add_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
         pass
 
-    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id,
-                           network=None):
+    def remove_floating_ip(self, floating_ip, fixed_ip, l3_interface_id):
         pass
 
     def add_vpn(self, public_ip, port, private_ip):
@@ -172,8 +155,5 @@ class NullL3(L3Driver):
     def remove_vpn(self, public_ip, port, private_ip):
         pass
 
-    def clean_conntrack(self, fixed_ip):
-        pass
-
     def teardown(self):
         pass
