@@ -555,27 +555,34 @@ class FloatingIP(object):
     def _associate_floating_ip(self, context, floating_address, fixed_address,
                                interface):
         """Performs db and driver calls to associate floating ip & fixed ip"""
-        # associate floating ip
-        self.db.floating_ip_fixed_ip_associate(context,
-                                               floating_address,
-                                               fixed_address,
-                                               self.host)
-        try:
-            # gogo driver time
-            self.l3driver.add_floating_ip(floating_address, fixed_address,
-                    interface)
-        except exception.ProcessExecutionError as e:
-            fixed_address = self.db.floating_ip_disassociate(context,
-                                                             floating_address)
-            if "Cannot find device" in str(e):
-                LOG.error(_('Interface %(interface)s not found'), locals())
-                raise exception.NoFloatingIpInterface(interface=interface)
-        payload = dict(project_id=context.project_id,
-                       floating_ip=floating_address)
-        notifier.notify(context,
-                        notifier.publisher_id("network"),
-                        'network.floating_ip.associate',
-                        notifier.INFO, payload=payload)
+
+        @utils.synchronized(unicode(floating_address))
+        def do_associate():
+            # associate floating ip
+            res = self.db.floating_ip_fixed_ip_associate(context,
+                                                         floating_address,
+                                                         fixed_address,
+                                                         self.host)
+            if not res:
+                # NOTE(vish): ip was already associated
+                return
+            try:
+                # gogo driver time
+                self.l3driver.add_floating_ip(floating_address, fixed_address,
+                        interface)
+            except exception.ProcessExecutionError as e:
+                self.db.floating_ip_disassociate(context, floating_address)
+                if "Cannot find device" in str(e):
+                    LOG.error(_('Interface %(interface)s not found'), locals())
+                    raise exception.NoFloatingIpInterface(interface=interface)
+
+            payload = dict(project_id=context.project_id,
+                           floating_ip=floating_address)
+            notifier.notify(context,
+                            notifier.publisher_id("network"),
+                            'network.floating_ip.associate',
+                            notifier.INFO, payload=payload)
+        do_associate()
 
     @wrap_check_policy
     def disassociate_floating_ip(self, context, address,
@@ -635,16 +642,31 @@ class FloatingIP(object):
     def _disassociate_floating_ip(self, context, address, interface):
         """Performs db and driver calls to disassociate floating ip"""
         # disassociate floating ip
-        fixed_address = self.db.floating_ip_disassociate(context, address)
 
-        if interface:
-            # go go driver time
-            self.l3driver.remove_floating_ip(address, fixed_address, interface)
-        payload = dict(project_id=context.project_id, floating_ip=address)
-        notifier.notify(context,
-                        notifier.publisher_id("network"),
-                        'network.floating_ip.disassociate',
-                        notifier.INFO, payload=payload)
+        @utils.synchronized(unicode(address))
+        def do_disassociate():
+            # NOTE(vish): Note that we are disassociating in the db before we
+            #             actually remove the ip address on the host. We are
+            #             safe from races on this host due to the decorator,
+            #             but another host might grab the ip right away. We
+            #             don't worry about this case because the miniscule
+            #             window where the ip is on both hosts shouldn't cause
+            #             any problems.
+            fixed_address = self.db.floating_ip_disassociate(context, address)
+
+            if not fixed_address:
+                # NOTE(vish): ip was already disassociated
+                return
+            if interface:
+                # go go driver time
+                self.l3driver.remove_floating_ip(address, fixed_address,
+                                                 interface)
+            payload = dict(project_id=context.project_id, floating_ip=address)
+            notifier.notify(context,
+                            notifier.publisher_id("network"),
+                            'network.floating_ip.disassociate',
+                            notifier.INFO, payload=payload)
+        do_disassociate()
 
     @wrap_check_policy
     def get_floating_ip(self, context, id):
@@ -1272,37 +1294,53 @@ class NetworkManager(manager.SchedulerDependentManager):
         address = None
         instance_ref = self.db.instance_get(context, instance_id)
 
-        if network['cidr']:
-            address = kwargs.get('address', None)
-            if address:
-                address = self.db.fixed_ip_associate(context,
-                                                     address,
-                                                     instance_ref['uuid'],
-                                                     network['id'])
-            else:
-                address = self.db.fixed_ip_associate_pool(context.elevated(),
-                                                          network['id'],
-                                                          instance_ref['uuid'])
-            self._do_trigger_security_group_members_refresh_for_instance(
-                                                                   instance_id)
-            get_vif = self.db.virtual_interface_get_by_instance_and_network
-            vif = get_vif(context, instance_ref['uuid'], network['id'])
-            values = {'allocated': True,
-                      'virtual_interface_id': vif['id']}
-            self.db.fixed_ip_update(context, address, values)
+        # Check the quota; can't put this in the API because we get
+        # called into from other places
+        try:
+            reservations = QUOTAS.reserve(context, fixed_ips=1)
+        except exception.OverQuota:
+            pid = context.project_id
+            LOG.warn(_("Quota exceeded for %(pid)s, tried to allocate "
+                       "fixed IP") % locals())
+            raise exception.FixedIpLimitExceeded()
 
-        name = instance_ref['display_name']
+        try:
+            if network['cidr']:
+                address = kwargs.get('address', None)
+                if address:
+                    address = self.db.fixed_ip_associate(context,
+                                                         address,
+                                                         instance_ref['uuid'],
+                                                         network['id'])
+                else:
+                    address = self.db.fixed_ip_associate_pool(
+                        context.elevated(), network['id'],
+                        instance_ref['uuid'])
+                self._do_trigger_security_group_members_refresh_for_instance(
+                    instance_id)
+                get_vif = self.db.virtual_interface_get_by_instance_and_network
+                vif = get_vif(context, instance_ref['uuid'], network['id'])
+                values = {'allocated': True,
+                          'virtual_interface_id': vif['id']}
+                self.db.fixed_ip_update(context, address, values)
 
-        if self._validate_instance_zone_for_dns_domain(context, instance_ref):
-            uuid = instance_ref['uuid']
-            self.instance_dns_manager.create_entry(name, address,
-                                                   "A",
-                                                   self.instance_dns_domain)
-            self.instance_dns_manager.create_entry(uuid, address,
-                                                   "A",
-                                                   self.instance_dns_domain)
-        self._setup_network_on_host(context, network)
-        return address
+            name = instance_ref['display_name']
+
+            if self._validate_instance_zone_for_dns_domain(context,
+                                                           instance_ref):
+                uuid = instance_ref['uuid']
+                self.instance_dns_manager.create_entry(
+                    name, address, "A", self.instance_dns_domain)
+                self.instance_dns_manager.create_entry(
+                    uuid, address, "A", self.instance_dns_domain)
+            self._setup_network_on_host(context, network)
+
+            QUOTAS.commit(context, reservations)
+            return address
+
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                QUOTAS.rollback(context, reservations)
 
     def deallocate_fixed_ip(self, context, address, host=None, teardown=True):
         """Returns a fixed ip to the pool."""
@@ -1312,6 +1350,13 @@ class NetworkManager(manager.SchedulerDependentManager):
                 context.elevated(read_deleted='yes'),
                 fixed_ip_ref['instance_uuid'])
 
+        try:
+            reservations = QUOTAS.reserve(context, fixed_ips=-1)
+        except Exception:
+            reservations = None
+            LOG.exception(_("Failed to update usages deallocating "
+                            "fixed IP"))
+
         self._do_trigger_security_group_members_refresh_for_instance(
             instance['uuid'])
 
@@ -1351,6 +1396,10 @@ class NetworkManager(manager.SchedulerDependentManager):
                 #             callback will get called by nova-dhcpbridge.
                 self.driver.release_dhcp(dev, address, vif['address'])
 
+        # Commit the reservations
+        if reservations:
+            QUOTAS.commit(context, reservations)
+
     def lease_fixed_ip(self, context, address):
         """Called by dhcp-bridge when ip is leased."""
         LOG.debug(_('Leased IP |%(address)s|'), locals(), context=context)
@@ -1597,7 +1646,7 @@ class NetworkManager(manager.SchedulerDependentManager):
 
             if network and cidr and subnet_v4:
                 self._create_fixed_ips(context, network['id'], fixed_cidr)
-        return networks
+        return jsonutils.to_primitive(networks)
 
     @wrap_check_policy
     def delete_network(self, context, fixed_range, uuid,
