@@ -21,8 +21,8 @@ from nova import db
 from nova import exception
 from nova import flags
 from nova import ipv6
-from nova import log as logging
 from nova.network import manager
+from nova.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -59,7 +59,7 @@ class QuantumNovaIPAMLib(object):
         """
         admin_context = context.elevated()
         subnet_size = len(netaddr.IPNetwork(cidr))
-        networks = manager.FlatManager.create_networks(self.net_manager,
+        networks = manager.FlatManager._do_create_networks(self.net_manager,
                     admin_context, label, cidr,
                     False, 1, subnet_size, cidr_v6, gateway,
                     gateway_v6, quantum_net_id, None, dns1, dns2,
@@ -127,9 +127,11 @@ class QuantumNovaIPAMLib(object):
         network = db.network_get_by_uuid(admin_context, quantum_net_id)
         address = None
         if network['cidr']:
+            instance = db.instance_get_by_uuid(context,
+                                               vif_rec['instance_uuid'])
             address = db.fixed_ip_associate_pool(admin_context,
                                                  network['id'],
-                                                 vif_rec['instance_id'])
+                                                 instance['uuid'])
             values = {'allocated': True,
                       'virtual_interface_id': vif_rec['id']}
             db.fixed_ip_update(admin_context, address, values)
@@ -212,7 +214,7 @@ class QuantumNovaIPAMLib(object):
         """
         admin_context = context.elevated()
         fixed_ips = db.fixed_ips_by_virtual_interface(admin_context,
-                                                         vif_ref['id'])
+                                                      vif_ref['id'])
         # NOTE(s0mik): Sets fixed-ip to deallocated, but leaves the entry
         # associated with the instance-id.  This prevents us from handing it
         # out again immediately, as allocating it to a new instance before
@@ -251,7 +253,7 @@ class QuantumNovaIPAMLib(object):
                 db.fixed_ip_disassociate(admin_context, fixed_ip['address'])
 
         if len(fixed_ips) == 0:
-            LOG.error(_('No fixed IPs to deallocate for vif %s') %
+            LOG.error(_('No fixed IPs to deallocate for vif %s'),
                       vif_ref['id'])
 
     def get_allocated_ips(self, context, subnet_id, project_id):
