@@ -1507,7 +1507,7 @@ class ConfigOpts(collections.Mapping):
                 if ('default' in info or 'override' in info):
                     continue
 
-                if self._get(opt.name, group) is None:
+                if self._get(opt.dest, group) is None:
                     raise RequiredOptError(opt.name, group)
 
     def _parse_cli_opts(self, args):
