@@ -25,12 +25,6 @@ class AffinityFilter(filters.BaseHostFilter):
     def __init__(self):
         self.compute_api = compute.API()
 
-    def _all_hosts(self, context):
-        all_hosts = {}
-        for instance in self.compute_api.get_all(context):
-            all_hosts[instance['uuid']] = instance['host']
-        return all_hosts
-
 
 class DifferentHostFilter(AffinityFilter):
     '''Schedule the instance on a different host from a set of instances.'''
@@ -38,15 +32,15 @@ class DifferentHostFilter(AffinityFilter):
     def host_passes(self, host_state, filter_properties):
         context = filter_properties['context']
         scheduler_hints = filter_properties.get('scheduler_hints') or {}
-        me = host_state.host
 
         affinity_uuids = scheduler_hints.get('different_host', [])
         if isinstance(affinity_uuids, basestring):
             affinity_uuids = [affinity_uuids]
         if affinity_uuids:
-            all_hosts = self._all_hosts(context)
-            return not any([i for i in affinity_uuids
-                              if all_hosts.get(i) == me])
+            return not self.compute_api.get_all(context,
+                                                {'host': host_state.host,
+                                                 'uuid': affinity_uuids,
+                                                 'deleted': False})
         # With no different_host key
         return True
 
@@ -59,16 +53,14 @@ class SameHostFilter(AffinityFilter):
     def host_passes(self, host_state, filter_properties):
         context = filter_properties['context']
         scheduler_hints = filter_properties.get('scheduler_hints') or {}
-        me = host_state.host
 
         affinity_uuids = scheduler_hints.get('same_host', [])
         if isinstance(affinity_uuids, basestring):
             affinity_uuids = [affinity_uuids]
         if affinity_uuids:
-            all_hosts = self._all_hosts(context)
-            return any([i for i
-                          in affinity_uuids
-                          if all_hosts.get(i) == me])
+            return self.compute_api.get_all(context, {'host': host_state.host,
+                                                      'uuid': affinity_uuids,
+                                                      'deleted': False})
         # With no same_host key
         return True
 
