@@ -15,8 +15,8 @@
 #    under the License.
 
 from nova import flags
-from nova import log as logging
 from nova.openstack.common import cfg
+from nova.openstack.common import log as logging
 from nova.scheduler import filters
 
 LOG = logging.getLogger(__name__)
@@ -38,6 +38,16 @@ class RamFilter(filters.BaseHostFilter):
         requested_ram = instance_type['memory_mb']
         free_ram_mb = host_state.free_ram_mb
         total_usable_ram_mb = host_state.total_usable_ram_mb
+
+        memory_mb_limit = total_usable_ram_mb * FLAGS.ram_allocation_ratio
         used_ram_mb = total_usable_ram_mb - free_ram_mb
-        return (total_usable_ram_mb * FLAGS.ram_allocation_ratio -
-                used_ram_mb >= requested_ram)
+        usable_ram = memory_mb_limit - used_ram_mb
+        if not usable_ram >= requested_ram:
+            LOG.debug(_("%(host_state)s does not have %(requested_ram)s MB "
+                    "usable ram, it only has %(usable_ram)s MB usable ram."),
+                    locals())
+            return False
+
+        # save oversubscription limit for compute node to test against:
+        host_state.limits['memory_mb'] = memory_mb_limit
+        return True
