@@ -1,4 +1,6 @@
-# Copyright (c) 2011 OpenStack Foundation
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright (c) 2011 OpenStack, LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,24 +23,29 @@ dynamic configuration.
 """
 
 import datetime
+import json
 import os
 
-from oslo_log import log as logging
-from oslo_serialization import jsonutils
-from oslo_utils import excutils
-from oslo_utils import timeutils
-
-import nova.conf
-from nova.i18n import _LE
+from nova import flags
+from nova.openstack.common import cfg
+from nova.openstack.common import log as logging
+from nova.openstack.common import timeutils
 
 
-CONF = nova.conf.CONF
+scheduler_json_config_location_opt = cfg.StrOpt(
+        'scheduler_json_config_location',
+        default='',
+        help='Absolute path to scheduler configuration JSON file.')
+
+FLAGS = flags.FLAGS
+FLAGS.register_opt(scheduler_json_config_location_opt)
 
 LOG = logging.getLogger(__name__)
 
 
 class SchedulerOptions(object):
-    """SchedulerOptions monitors a local .json file for changes and loads it
+    """
+    SchedulerOptions monitors a local .json file for changes and loads it
     if needed. This file is converted to a data structure and passed into
     the filtering and weighing functions which can use it for dynamic
     configuration.
@@ -58,18 +65,18 @@ class SchedulerOptions(object):
         """Get the last modified datetime. Broken out for testing."""
         try:
             return os.path.getmtime(filename)
-        except os.error:
-            with excutils.save_and_reraise_exception():
-                LOG.exception(_LE("Could not stat scheduler options file "
-                                  "%(filename)s"),
-                              {'filename': filename})
+        except os.error, e:
+            LOG.exception(_("Could not stat scheduler options file "
+                            "%(filename)s: '%(e)s'"), locals())
+            raise
 
     def _load_file(self, handle):
         """Decode the JSON file. Broken out for testing."""
         try:
-            return jsonutils.load(handle)
-        except ValueError:
-            LOG.exception(_LE("Could not decode scheduler options"))
+            return json.load(handle)
+        except ValueError, e:
+            LOG.exception(_("Could not decode scheduler options: "
+                            "'%(e)s'") % locals())
             return {}
 
     def _get_time_now(self):
@@ -79,7 +86,7 @@ class SchedulerOptions(object):
     def get_configuration(self, filename=None):
         """Check the json file for changes and load it if needed."""
         if not filename:
-            filename = CONF.scheduler_json_config_location
+            filename = FLAGS.scheduler_json_config_location
         if not filename:
             return self.data
         if self.last_checked:
@@ -87,15 +94,9 @@ class SchedulerOptions(object):
             if now - self.last_checked < datetime.timedelta(minutes=5):
                 return self.data
 
-        self.last_checked = self._get_time_now()
-        LOG.debug('Start to check scheduler configuration file at: %s',
-                  self.last_checked)
-
         last_modified = self._get_file_timestamp(filename)
         if (not last_modified or not self.last_modified or
-                last_modified > self.last_modified):
-            LOG.debug('Start to load scheduler configuration file which'
-                      'modified at: %s', last_modified)
+            last_modified > self.last_modified):
             self.data = self._load_file(self._get_file_handle(filename))
             self.last_modified = last_modified
         if not self.data:
