@@ -15,26 +15,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import webob
 from lxml import etree
+import webob
 
-from nova.api.openstack import wsgi
 from nova.api.openstack.compute.contrib import quotas
+from nova.api.openstack import wsgi
 from nova import test
 from nova.tests.api.openstack import fakes
 
 
 def quota_set(id):
     return {'quota_set': {'id': id, 'metadata_items': 128, 'volumes': 10,
-            'gigabytes': 1000, 'ram': 51200, 'floating_ips': 10,
-            'instances': 10, 'injected_files': 5, 'cores': 20,
-            'injected_file_content_bytes': 10240,
-            'security_groups': 10, 'security_group_rules': 20}}
-
-
-def quota_set_list():
-    return {'quota_set_list': [quota_set('1234'), quota_set('5678'),
-                               quota_set('update_me')]}
+                          'gigabytes': 1000, 'ram': 51200, 'floating_ips': 10,
+                          'fixed_ips': -1, 'instances': 10,
+                          'injected_files': 5, 'cores': 20,
+                          'injected_file_content_bytes': 10240,
+                          'security_groups': 10, 'security_group_rules': 20,
+                          'key_pairs': 100, 'injected_file_path_bytes': 255}}
 
 
 class QuotaSetsTest(test.TestCase):
@@ -50,16 +47,18 @@ class QuotaSetsTest(test.TestCase):
             'ram': 51200,
             'volumes': 10,
             'floating_ips': 10,
+            'fixed_ips': -1,
             'metadata_items': 128,
             'gigabytes': 1000,
             'injected_files': 5,
+            'injected_file_path_bytes': 255,
             'injected_file_content_bytes': 10240,
             'security_groups': 10,
             'security_group_rules': 20,
+            'key_pairs': 100,
             }
 
-        quota_set = quotas.QuotaSetsController()._format_quota_set('1234',
-                                                            raw_quota_set)
+        quota_set = self.controller._format_quota_set('1234', raw_quota_set)
         qs = quota_set['quota_set']
 
         self.assertEqual(qs['id'], '1234')
@@ -69,11 +68,14 @@ class QuotaSetsTest(test.TestCase):
         self.assertEqual(qs['volumes'], 10)
         self.assertEqual(qs['gigabytes'], 1000)
         self.assertEqual(qs['floating_ips'], 10)
+        self.assertEqual(qs['fixed_ips'], -1)
         self.assertEqual(qs['metadata_items'], 128)
         self.assertEqual(qs['injected_files'], 5)
+        self.assertEqual(qs['injected_file_path_bytes'], 255)
         self.assertEqual(qs['injected_file_content_bytes'], 10240)
         self.assertEqual(qs['security_groups'], 10)
         self.assertEqual(qs['security_group_rules'], 20)
+        self.assertEqual(qs['key_pairs'], 100)
 
     def test_quotas_defaults(self):
         uri = '/v2/fake_tenant/os-quota-sets/fake_tenant/defaults'
@@ -89,11 +91,14 @@ class QuotaSetsTest(test.TestCase):
                     'volumes': 10,
                     'gigabytes': 1000,
                     'floating_ips': 10,
+                    'fixed_ips': -1,
                     'metadata_items': 128,
                     'injected_files': 5,
+                    'injected_file_path_bytes': 255,
                     'injected_file_content_bytes': 10240,
                     'security_groups': 10,
                     'security_group_rules': 20,
+                    'key_pairs': 100,
                     }}
 
         self.assertEqual(res_dict, expected)
@@ -115,9 +120,12 @@ class QuotaSetsTest(test.TestCase):
                               'ram': 51200, 'volumes': 10,
                               'gigabytes': 1000, 'floating_ips': 10,
                               'metadata_items': 128, 'injected_files': 5,
+                              'fixed_ips': -1,
                               'injected_file_content_bytes': 10240,
+                              'injected_file_path_bytes': 255,
                               'security_groups': 10,
-                              'security_group_rules': 20}}
+                              'security_group_rules': 20,
+                              'key_pairs': 100, 'fixed_ips': -1}}
 
         req = fakes.HTTPRequest.blank('/v2/fake4/os-quota-sets/update_me',
                                       use_admin_context=True)
@@ -130,14 +138,28 @@ class QuotaSetsTest(test.TestCase):
                               'ram': 51200, 'volumes': 10,
                               'gigabytes': 1000, 'floating_ips': 10,
                               'metadata_items': 128, 'injected_files': 5,
+                              'fixed_ips': -1,
                               'injected_file_content_bytes': 10240,
                               'security_groups': 10,
-                              'security_group_rules': 20}}
+                              'security_group_rules': 20,
+                              'key_pairs': 100}}
 
         req = fakes.HTTPRequest.blank('/v2/fake4/os-quota-sets/update_me')
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.update,
                           req, 'update_me', body)
 
+    def test_quotas_update_invalid_limit(self):
+        body = {'quota_set': {'instances': -2, 'cores': -2,
+                              'ram': -2, 'volumes': -2,
+                              'gigabytes': -2, 'floating_ips': -2,
+                              'metadata_items': -2, 'injected_files': -2,
+                              'injected_file_content_bytes': -2}}
+
+        req = fakes.HTTPRequest.blank('/v2/fake4/os-quota-sets/update_me',
+                                      use_admin_context=True)
+        self.assertRaises(webob.exc.HTTPBadRequest, self.controller.update,
+                          req, 'update_me', body)
+
 
 class QuotaXMLSerializerTest(test.TestCase):
     def setUp(self):
@@ -149,15 +171,18 @@ class QuotaXMLSerializerTest(test.TestCase):
         exemplar = dict(quota_set=dict(
                 id='project_id',
                 metadata_items=10,
+                injected_file_path_bytes=255,
                 injected_file_content_bytes=20,
                 volumes=30,
                 gigabytes=40,
                 ram=50,
                 floating_ips=60,
+                fixed_ips=-1,
                 instances=70,
                 injected_files=80,
                 security_groups=10,
                 security_group_rules=20,
+                key_pairs=100,
                 cores=90))
         text = self.serializer.serialize(exemplar)
 
@@ -179,10 +204,12 @@ class QuotaXMLSerializerTest(test.TestCase):
                 gigabytes='40',
                 ram='50',
                 floating_ips='60',
+                fixed_ips='-1',
                 instances='70',
                 injected_files='80',
                 security_groups='10',
                 security_group_rules='20',
+                key_pairs='100',
                 cores='90'))
         intext = ("<?xml version='1.0' encoding='UTF-8'?>\n"
                   '<quota_set>'
@@ -193,10 +220,12 @@ class QuotaXMLSerializerTest(test.TestCase):
                   '<gigabytes>40</gigabytes>'
                   '<ram>50</ram>'
                   '<floating_ips>60</floating_ips>'
+                  '<fixed_ips>-1</fixed_ips>'
                   '<instances>70</instances>'
                   '<injected_files>80</injected_files>'
                   '<security_groups>10</security_groups>'
                   '<security_group_rules>20</security_group_rules>'
+                  '<key_pairs>100</key_pairs>'
                   '<cores>90</cores>'
                   '</quota_set>')
 
