@@ -17,15 +17,14 @@
 """This modules stubs out functions in nova.utils."""
 
 import re
-import types
 
 from eventlet import greenthread
 
 from nova import exception
-from nova import log as logging
+from nova.openstack.common import log as logging
 from nova import utils
 
-LOG = logging.getLogger('nova.tests.fake_utils')
+LOG = logging.getLogger(__name__)
 
 _fake_execute_repliers = []
 _fake_execute_log = []
@@ -94,7 +93,7 @@ def fake_execute(*cmd_parts, **kwargs):
                                   run_as_root=run_as_root,
                                   check_exit_code=check_exit_code)
         except exception.ProcessExecutionError as e:
-            LOG.debug(_('Faked command raised an exception %s' % str(e)))
+            LOG.debug(_('Faked command raised an exception %s'), e)
             raise
 
     stdout = reply[0]
