@@ -69,8 +69,13 @@ VIR_DOMAIN_SHUTOFF = 5
 VIR_DOMAIN_CRASHED = 6
 
 VIR_DOMAIN_XML_SECURE = 1
+
 VIR_DOMAIN_UNDEFINE_MANAGED_SAVE = 1
 
+VIR_DOMAIN_AFFECT_CURRENT = 0
+VIR_DOMAIN_AFFECT_LIVE = 1
+VIR_DOMAIN_AFFECT_CONFIG = 2
+
 VIR_CPU_COMPARE_ERROR = -1
 VIR_CPU_COMPARE_INCOMPATIBLE = 0
 VIR_CPU_COMPARE_IDENTICAL = 1
@@ -174,6 +179,7 @@ class Domain(object):
         self._def = self._parse_definition(xml)
         self._has_saved_state = False
         self._snapshots = {}
+        self._id = self._connection._id_counter
 
     def _parse_definition(self, xml):
         try:
@@ -294,6 +300,9 @@ class Domain(object):
         self._state = VIR_DOMAIN_SHUTOFF
         self._connection._mark_not_running(self)
 
+    def ID(self):
+        return self._id
+
     def name(self):
         return self._def['name']
 
@@ -334,11 +343,20 @@ class Domain(object):
         self._def['devices']['disks'] += [disk_info]
         return True
 
+    def attachDeviceFlags(self, xml, flags):
+        if (flags & VIR_DOMAIN_AFFECT_LIVE and
+            self._state != VIR_DOMAIN_RUNNING):
+            raise libvirtError("AFFECT_LIVE only allowed for running domains!")
+        self.attachDevice(xml)
+
     def detachDevice(self, xml):
         disk_info = _parse_disk_info(etree.fromstring(xml))
         disk_info['_attached'] = True
         return disk_info in self._def['devices']['disks']
 
+    def detachDeviceFlags(self, xml, _flags):
+        self.detachDevice(xml)
+
     def XMLDesc(self, flags):
         disks = ''
         for disk in self._def['devices']['disks']:
@@ -502,6 +520,8 @@ class Connection(object):
         if dom._transient:
             self._undefine(dom)
 
+        dom._id = -1
+
         for (k, v) in self._running_vms.iteritems():
             if v == dom:
                 del self._running_vms[k]
