@@ -14,7 +14,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import os.path
+import shutil
 import string
+import tempfile
 
 from nova import test
 from nova.volume import iscsi
@@ -28,9 +31,16 @@ class TargetAdminTestCase(object):
         self.tid = 1
         self.target_name = 'iqn.2011-09.org.foo.bar:blaa'
         self.lun = 10
-        self.path = '/foo/bar/blaa'
+        self.path = '/foo'
+        self.vol_id = 'blaa'
 
         self.script_template = None
+        self.stubs.Set(os.path, 'isfile', lambda _: True)
+        self.stubs.Set(os, 'unlink', lambda _: '')
+        self.stubs.Set(iscsi.TgtAdm, '_get_target', self.fake_get_target)
+
+    def fake_get_target(obj, iqn):
+        return 1
 
     def get_script_params(self):
         return {'tid': self.tid,
@@ -65,11 +75,10 @@ class TargetAdminTestCase(object):
     def run_commands(self):
         tgtadm = iscsi.get_target_admin()
         tgtadm.set_execute(self.fake_execute)
-        tgtadm.new_target(self.target_name, self.tid)
-        tgtadm.show_target(self.tid)
-        tgtadm.new_logicalunit(self.tid, self.lun, self.path)
-        tgtadm.delete_logicalunit(self.tid, self.lun)
-        tgtadm.delete_target(self.tid)
+        tgtadm.create_iscsi_target(self.target_name, self.tid,
+                self.lun, self.path)
+        tgtadm.show_target(self.tid, iqn=self.target_name)
+        tgtadm.remove_iscsi_target(self.tid, self.lun, self.vol_id)
 
     def test_target_admin(self):
         self.clear_cmds()
@@ -82,23 +91,19 @@ class TgtAdmTestCase(test.TestCase, TargetAdminTestCase):
     def setUp(self):
         super(TgtAdmTestCase, self).setUp()
         TargetAdminTestCase.setUp(self)
+        self.persist_tempdir = tempfile.mkdtemp()
         self.flags(iscsi_helper='tgtadm')
+        self.flags(volumes_dir=self.persist_tempdir)
         self.script_template = "\n".join([
-        "tgtadm --op new --lld=iscsi --mode=target --tid=%(tid)s "
-                "--targetname=%(target_name)s",
-        "tgtadm --op bind --lld=iscsi --mode=target --initiator-address=ALL "
-                "--tid=%(tid)s",
-        "tgtadm --op show --lld=iscsi --mode=target --tid=%(tid)s",
-        "tgtadm --op new --lld=iscsi --mode=logicalunit --tid=%(tid)s "
-                "--lun=%(lun)d --backing-store=%(path)s",
-        "tgtadm --op delete --lld=iscsi --mode=logicalunit --tid=%(tid)s "
-                "--lun=%(lun)d",
-        "tgtadm --op delete --lld=iscsi --mode=target --tid=%(tid)s"])
+        'tgt-admin --update iqn.2011-09.org.foo.bar:blaa',
+        'tgt-admin --delete iqn.2010-10.org.openstack:volume-blaa'])
 
-    def get_script_params(self):
-        params = super(TgtAdmTestCase, self).get_script_params()
-        params['lun'] += 1
-        return params
+    def tearDown(self):
+        try:
+            shutil.rmtree(self.persist_tempdir)
+        except OSError:
+            pass
+        super(TgtAdmTestCase, self).tearDown()
 
 
 class IetAdmTestCase(test.TestCase, TargetAdminTestCase):
@@ -108,9 +113,9 @@ class IetAdmTestCase(test.TestCase, TargetAdminTestCase):
         TargetAdminTestCase.setUp(self)
         self.flags(iscsi_helper='ietadm')
         self.script_template = "\n".join([
-        "ietadm --op new --tid=%(tid)s --params Name=%(target_name)s",
-        "ietadm --op show --tid=%(tid)s",
-        "ietadm --op new --tid=%(tid)s --lun=%(lun)d "
-                "--params Path=%(path)s,Type=fileio",
-        "ietadm --op delete --tid=%(tid)s --lun=%(lun)d",
-        "ietadm --op delete --tid=%(tid)s"])
+        'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
+        'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
+                '--params Path=%(path)s,Type=fileio',
+        'ietadm --op show --tid=%(tid)s',
+        'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
+        'ietadm --op delete --tid=%(tid)s'])
