@@ -22,14 +22,15 @@ Unit Tests for remote procedure calls using queue
 
 import mox
 
+
 from nova import context
 from nova import db
 from nova import exception
 from nova import flags
-from nova.openstack.common import cfg
-from nova import test
-from nova import service
 from nova import manager
+from nova.openstack.common import cfg
+from nova import service
+from nova import test
 from nova import wsgi
 
 
@@ -38,7 +39,7 @@ test_service_opts = [
                default="nova.tests.test_service.FakeManager",
                help="Manager for testing"),
     cfg.StrOpt("test_service_listen",
-               default=None,
+               default='127.0.0.1',
                help="Host to bind test service to"),
     cfg.IntOpt("test_service_listen_port",
                default=0,
@@ -200,7 +201,6 @@ class TestWSGIService(test.TestCase):
 
     def test_service_random_port(self):
         test_service = service.WSGIService("test_service")
-        self.assertEquals(0, test_service.port)
         test_service.start()
         self.assertNotEqual(0, test_service.port)
         test_service.stop()
@@ -214,8 +214,7 @@ class TestLauncher(test.TestCase):
         self.service = service.WSGIService("test_service")
 
     def test_launch_app(self):
-        self.assertEquals(0, self.service.port)
         launcher = service.Launcher()
         launcher.launch_server(self.service)
-        self.assertEquals(0, self.service.port)
+        self.assertNotEquals(0, self.service.port)
         launcher.stop()
