@@ -22,25 +22,23 @@ to the write using a LightQueue as a Pipe between the reader and the writer.
 
 from eventlet import event
 from eventlet import greenthread
-from eventlet.queue import LightQueue
-
-from glance import client
+from eventlet import queue
 
 from nova import exception
-from nova import log as logging
+from nova.openstack.common import log as logging
 
-LOG = logging.getLogger("nova.virt.vmwareapi.io_util")
+LOG = logging.getLogger(__name__)
 
 IO_THREAD_SLEEP_TIME = .01
 GLANCE_POLL_INTERVAL = 5
 
 
-class ThreadSafePipe(LightQueue):
+class ThreadSafePipe(queue.LightQueue):
     """The pipe to hold the data which the reader writes to and the writer
     reads from."""
 
     def __init__(self, maxsize, transfer_size):
-        LightQueue.__init__(self, maxsize)
+        queue.LightQueue.__init__(self, maxsize)
         self.transfer_size = transfer_size
         self.transferred = 0
 
@@ -68,12 +66,14 @@ class GlanceWriteThread(object):
     """Ensures that image data is written to in the glance client and that
     it is in correct ('active')state."""
 
-    def __init__(self, input, glance_client, image_id, image_meta=None):
+    def __init__(self, context, input, image_service, image_id,
+            image_meta=None):
         if not image_meta:
             image_meta = {}
 
+        self.context = context
         self.input = input
-        self.glance_client = glance_client
+        self.image_service = image_service
         self.image_id = image_id
         self.image_meta = image_meta
         self._running = False
@@ -84,36 +84,37 @@ class GlanceWriteThread(object):
         def _inner():
             """Function to do the image data transfer through an update
             and thereon checks if the state is 'active'."""
-            self.glance_client.update_image(self.image_id,
-                                            image_meta=self.image_meta,
-                                            image_data=self.input)
+            self.image_service.update(self.context,
+                                      self.image_id,
+                                      self.image_meta,
+                                      data=self.input)
             self._running = True
             while self._running:
                 try:
-                    image_status = \
-                        self.glance_client.get_image_meta(self.image_id).get(
-                                                                "status")
+                    image_meta = self.image_service.show(self.context,
+                                                         self.image_id)
+                    image_status = image_meta.get("status")
                     if image_status == "active":
                         self.stop()
                         self.done.send(True)
                     # If the state is killed, then raise an exception.
                     elif image_status == "killed":
                         self.stop()
-                        exc_msg = _("Glance image %s is in killed state") %\
-                                    self.image_id
-                        LOG.exception(exc_msg)
-                        self.done.send_exception(exception.Error(exc_msg))
+                        msg = (_("Glance image %s is in killed state") %
+                                 self.image_id)
+                        LOG.error(msg)
+                        self.done.send_exception(exception.NovaException(msg))
                     elif image_status in ["saving", "queued"]:
                         greenthread.sleep(GLANCE_POLL_INTERVAL)
                     else:
                         self.stop()
-                        exc_msg = _("Glance image "
+                        msg = _("Glance image "
                                     "%(image_id)s is in unknown state "
                                     "- %(state)s") % {
                                             "image_id": self.image_id,
                                             "state": image_status}
-                        LOG.exception(exc_msg)
-                        self.done.send_exception(exception.Error(exc_msg))
+                        LOG.error(msg)
+                        self.done.send_exception(exception.NovaException(msg))
                 except Exception, exc:
                     self.stop()
                     self.done.send_exception(exc)
