@@ -17,42 +17,35 @@
 
 """VIF drivers for VMWare."""
 
-from nova import db
 from nova import exception
 from nova import flags
-from nova import log as logging
-from nova import utils
-from nova.virt.vif import VIFDriver
-from nova.virt.vmwareapi_conn import VMWareAPISession
+from nova.openstack.common import log as logging
+from nova.virt import vif
 from nova.virt.vmwareapi import network_utils
 
 
-LOG = logging.getLogger("nova.virt.vmwareapi.vif")
+LOG = logging.getLogger(__name__)
 
 FLAGS = flags.FLAGS
+FLAGS.set_default('vmwareapi_vlan_interface', 'vmnic0')
 
 
-class VMWareVlanBridgeDriver(VIFDriver):
+class VMWareVlanBridgeDriver(vif.VIFDriver):
     """VIF Driver to setup bridge/VLAN networking using VMWare API."""
 
-    def plug(self, instance, network, mapping):
+    def plug(self, instance, vif):
+        """Plug the VIF to specified instance using information passed.
+        Currently we are plugging the VIF(s) during instance creation itself.
+        We can use this method when we add support to add additional NIC to
+        an existing instance."""
+        pass
+
+    def ensure_vlan_bridge(self, session, network):
         """Create a vlan and bridge unless they already exist."""
         vlan_num = network['vlan']
         bridge = network['bridge']
-        bridge_interface = network['bridge_interface']
+        vlan_interface = FLAGS.vmwareapi_vlan_interface
 
-        # Open vmwareapi session
-        host_ip = FLAGS.vmwareapi_host_ip
-        host_username = FLAGS.vmwareapi_host_username
-        host_password = FLAGS.vmwareapi_host_password
-        if not host_ip or host_username is None or host_password is None:
-            raise Exception(_('Must specify vmwareapi_host_ip, '
-                              'vmwareapi_host_username '
-                              'and vmwareapi_host_password to use '
-                              'connection_type=vmwareapi'))
-        session = VMWareAPISession(host_ip, host_username, host_password,
-                                   FLAGS.vmwareapi_api_retry_count)
-        vlan_interface = bridge_interface
         # Check if the vlan_interface physical network adapter exists on the
         # host.
         if not network_utils.check_if_vlan_interface_exists(session,
@@ -76,9 +69,8 @@ class VMWareVlanBridgeDriver(VIFDriver):
                                             vswitch_associated, vlan_num)
         else:
             # Get the vlan id and vswitch corresponding to the port group
-            pg_vlanid, pg_vswitch = \
-                network_utils.get_vlanid_and_vswitch_for_portgroup(session,
-                                                                   bridge)
+            _get_pg_info = network_utils.get_vlanid_and_vswitch_for_portgroup
+            pg_vlanid, pg_vswitch = _get_pg_info(session, bridge)
 
             # Check if the vswitch associated is proper
             if pg_vswitch != vswitch_associated:
@@ -91,5 +83,7 @@ class VMWareVlanBridgeDriver(VIFDriver):
                 raise exception.InvalidVLANTag(bridge=bridge, tag=vlan_num,
                                                pgroup=pg_vlanid)
 
-    def unplug(self, instance, network, mapping):
+    def unplug(self, instance, vif):
+        """Cleanup operations like deleting port group if no instance
+        is associated with it."""
         pass
