@@ -172,7 +172,7 @@ def create_vdi(name_label, sr_ref, **kwargs):
         'other_config': {},
         'location': '',
         'xenstore_data': {},
-        'sm_config': {},
+        'sm_config': {'vhd-parent': None},
         'physical_utilisation': '123',
         'managed': True,
     }
@@ -564,12 +564,18 @@ class SessionBase(object):
     def _plugin_pickle_noop(self, method, args):
         return pickle.dumps(None)
 
+    def _plugin_migration_transfer_vhd(self, method, args):
+        kwargs = pickle.loads(args['params'])['kwargs']
+        vdi_ref = self.xenapi_request('VDI.get_by_uuid',
+                (kwargs['vdi_uuid'], ))
+        assert vdi_ref
+        return pickle.dumps(None)
+
     _plugin_glance_upload_vhd = _plugin_pickle_noop
     _plugin_kernel_copy_vdi = _plugin_noop
     _plugin_kernel_create_kernel_ramdisk = _plugin_noop
     _plugin_kernel_remove_kernel_ramdisk = _plugin_noop
     _plugin_migration_move_vhds_into_sr = _plugin_noop
-    _plugin_migration_transfer_vhd = _plugin_pickle_noop
 
     def _plugin_xenhost_host_data(self, method, args):
             return jsonutils.dumps({'host_memory': {'total': 10,
