@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2010 OpenStack LLC.
+# Copyright 2010-2011 OpenStack LLC.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -22,22 +22,23 @@ XenServer hosts.
 """
 
 import os
-import subprocess
 import sys
 
+import novalib
+
 # This is written to Python 2.4, since that is what is available on XenServer
 import simplejson as json
 
 
 def main(dom_id, command, only_this_vif=None):
-    xsls = execute('/usr/bin/xenstore-ls',
-                   '/local/domain/%s/vm-data/networking' % dom_id, True)
+    xsls = novalib.execute_get_output('/usr/bin/xenstore-ls',
+                              '/local/domain/%s/vm-data/networking' % dom_id)
     macs = [line.split("=")[0].strip() for line in xsls.splitlines()]
 
     for mac in macs:
-        xsread = execute('/usr/bin/enstore-read',
-                         '/local/domain/%s/vm-data/networking/%s' %
-                         (dom_id, mac), True)
+        xsread = novalib.execute_get_output('/usr/bin/xenstore-read',
+                                    '/local/domain/%s/vm-data/networking/%s' %
+                                    (dom_id, mac))
         data = json.loads(xsread)
         for ip in data['ips']:
             if data["label"] == "public":
@@ -52,24 +53,13 @@ def main(dom_id, command, only_this_vif=None):
                 apply_iptables_rules(command, params)
 
 
-def execute(*command, return_stdout=False):
-    devnull = open(os.devnull, 'w')
-    command = map(str, command)
-    proc = subprocess.Popen(command, close_fds=True,
-                            stdout=subprocess.PIPE, stderr=devnull)
-    devnull.close()
-    if return_stdout:
-        return proc.stdout.read()
-    else:
-        return None
-
 # A note about adding rules:
 #   Whenever we add any rule to iptables, arptables or ebtables we first
 #   delete the same rule to ensure the rule only exists once.
 
 
 def apply_iptables_rules(command, params):
-    iptables = lambda *rule: execute('/sbin/iptables', *rule)
+    iptables = lambda *rule: novalib.execute('/sbin/iptables', *rule)
 
     iptables('-D', 'FORWARD', '-m', 'physdev',
              '--physdev-in', params['VIF'],
@@ -83,7 +73,7 @@ def apply_iptables_rules(command, params):
 
 
 def apply_arptables_rules(command, params):
-    arptables = lambda *rule: execute('/sbin/arptables', *rule)
+    arptables = lambda *rule: novalib.execute('/sbin/arptables', *rule)
 
     arptables('-D', 'FORWARD', '--opcode', 'Request',
               '--in-interface', params['VIF'],
@@ -108,13 +98,13 @@ def apply_arptables_rules(command, params):
 
 
 def apply_ebtables_rules(command, params):
-    ebtables = lambda *rule: execute("/sbin/ebtables", *rule)
+    ebtables = lambda *rule: novalib.execute("/sbin/ebtables", *rule)
 
     ebtables('-D', 'FORWARD', '-p', '0806', '-o', params['VIF'],
              '--arp-ip-dst', params['IP'],
              '-j', 'ACCEPT')
-    ebtables('-D', 'FORWARD', '-p', '0800', '-o',
-             params['VIF'], '--ip-dst', params['IP'],
+    ebtables('-D', 'FORWARD', '-p', '0800', '-o', params['VIF'],
+             '--ip-dst', params['IP'],
              '-j', 'ACCEPT')
     if command == 'online':
         ebtables('-A', 'FORWARD', '-p', '0806',
@@ -135,8 +125,8 @@ def apply_ebtables_rules(command, params):
 
 if __name__ == "__main__":
     if len(sys.argv) < 3:
-        print "usage: %s dom_id online|offline [vif]" % \
-               os.path.basename(sys.argv[0])
+        print ("usage: %s dom_id online|offline [vif]" %
+               os.path.basename(sys.argv[0]))
         sys.exit(1)
     else:
         dom_id, command = sys.argv[1:3]
