@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright 2011 OpenStack Foundation
+# Copyright 2011 OpenStack, LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,36 +19,25 @@
 import doctest
 import os
 import sys
-
-from oslo_config import cfg
-from oslo_utils import timeutils
 import XenAPI
 
+
 possible_topdir = os.getcwd()
 if os.path.exists(os.path.join(possible_topdir, "nova", "__init__.py")):
         sys.path.insert(0, possible_topdir)
 
-from nova import config
+
 from nova import context
-import nova.conf
 from nova import db
 from nova import exception
-from nova.virt import virtapi
+from nova import flags
+from nova.openstack.common import cfg
+from nova.openstack.common import timeutils
 from nova.virt.xenapi import driver as xenapi_driver
 
 
-cleaner_opts = [
-    cfg.IntOpt('zombie_instance_updated_at_window',
-               default=172800,
-               help='Number of seconds zombie instances are cleaned up.'),
-]
-
-cli_opt = cfg.StrOpt('command',
-                     help='Cleaner command')
-
-CONF = nova.conf.CONF
-CONF.register_opts(cleaner_opts)
-CONF.register_cli_opt(cli_opt)
+CONF = cfg.CONF
+flags.DECLARE("resize_confirm_window", "nova.compute.manager")
 
 
 ALLOWED_COMMANDS = ["list-vdis", "clean-vdis", "list-instances",
@@ -56,7 +45,7 @@ ALLOWED_COMMANDS = ["list-vdis", "clean-vdis", "list-instances",
 
 
 def call_xenapi(xenapi, method, *args):
-    """Make a call to xapi."""
+    """Make a call to xapi"""
     return xenapi._session.call_xenapi(method, *args)
 
 
@@ -69,7 +58,7 @@ def find_orphaned_instances(xenapi):
     for vm_ref, vm_rec in _get_applicable_vm_recs(xenapi):
         try:
             uuid = vm_rec['other_config']['nova_uuid']
-            instance = db.instance_get_by_uuid(ctxt, uuid)
+            instance = db.api.instance_get_by_uuid(ctxt, uuid)
         except (KeyError, exception.InstanceNotFound):
             # NOTE(jk0): Err on the side of caution here. If we don't know
             # anything about the particular instance, ignore it.
@@ -105,7 +94,7 @@ def _get_applicable_vm_recs(xenapi):
     for vm_ref in call_xenapi(xenapi, 'VM.get_all'):
         try:
             vm_rec = call_xenapi(xenapi, 'VM.get_record', vm_ref)
-        except XenAPI.Failure as e:
+        except XenAPI.Failure, e:
             if e.details[0] != 'HANDLE_INVALID':
                 raise
             continue
@@ -122,14 +111,16 @@ def print_xen_object(obj_type, obj, indent_level=0, spaces_per_indent=4):
 
         VM (abcd-abcd-abcd): 'name label here'
     """
+    if not CONF.verbose:
+        return
     uuid = obj["uuid"]
     try:
         name_label = obj["name_label"]
     except KeyError:
         name_label = ""
-    msg = "%s (%s) '%s'" % (obj_type, uuid, name_label)
+    msg = "%(obj_type)s (%(uuid)s) '%(name_label)s'" % locals()
     indent = " " * spaces_per_indent * indent_level
-    print("".join([indent, msg]))
+    print "".join([indent, msg])
 
 
 def _find_vdis_connected_to_vm(xenapi, connected_vdi_uuids):
@@ -161,7 +152,7 @@ def _find_vdis_connected_to_vm(xenapi, connected_vdi_uuids):
                 try:
                     cur_vdi_rec = call_xenapi(xenapi, 'VDI.get_record',
                             cur_vdi_ref)
-                except XenAPI.Failure as e:
+                except XenAPI.Failure, e:
                     if e.details[0] != 'HANDLE_INVALID':
                         raise
                     break
@@ -176,7 +167,7 @@ def _find_vdis_connected_to_vm(xenapi, connected_vdi_uuids):
         for vbd_ref in vbd_refs:
             try:
                 vbd_rec = call_xenapi(xenapi, 'VBD.get_record', vbd_ref)
-            except XenAPI.Failure as e:
+            except XenAPI.Failure, e:
                 if e.details[0] != 'HANDLE_INVALID':
                     raise
                 continue
@@ -191,7 +182,7 @@ def _find_vdis_connected_to_vm(xenapi, connected_vdi_uuids):
 
             try:
                 vdi_rec = call_xenapi(xenapi, 'VDI.get_record', vbd_vdi_ref)
-            except XenAPI.Failure as e:
+            except XenAPI.Failure, e:
                 if e.details[0] != 'HANDLE_INVALID':
                     raise
                 continue
@@ -210,7 +201,7 @@ def _find_all_vdis_and_system_vdis(xenapi, all_vdi_uuids, connected_vdi_uuids):
     for vdi_ref in call_xenapi(xenapi, 'VDI.get_all'):
         try:
             vdi_rec = call_xenapi(xenapi, 'VDI.get_record', vdi_ref)
-        except XenAPI.Failure as e:
+        except XenAPI.Failure, e:
             if e.details[0] != 'HANDLE_INVALID':
                 raise
             continue
@@ -243,58 +234,65 @@ def find_orphaned_vdi_uuids(xenapi):
 def list_orphaned_vdis(vdi_uuids):
     """List orphaned VDIs."""
     for vdi_uuid in vdi_uuids:
-        print("ORPHANED VDI (%s)" % vdi_uuid)
+        if CONF.verbose:
+            print "ORPHANED VDI (%s)" % vdi_uuid
+        else:
+            print vdi_uuid
 
 
 def clean_orphaned_vdis(xenapi, vdi_uuids):
     """Clean orphaned VDIs."""
     for vdi_uuid in vdi_uuids:
-        print("CLEANING VDI (%s)" % vdi_uuid)
+        if CONF.verbose:
+            print "CLEANING VDI (%s)" % vdi_uuid
 
         vdi_ref = call_xenapi(xenapi, 'VDI.get_by_uuid', vdi_uuid)
         try:
             call_xenapi(xenapi, 'VDI.destroy', vdi_ref)
-        except XenAPI.Failure as exc:
-            sys.stderr.write("Skipping %s: %s" % (vdi_uuid, exc))
+        except XenAPI.Failure, exc:
+            print >> sys.stderr, "Skipping %s: %s" % (vdi_uuid, exc)
 
 
 def list_orphaned_instances(orphaned_instances):
     """List orphaned instances."""
     for vm_ref, vm_rec, orphaned_instance in orphaned_instances:
-        print("ORPHANED INSTANCE (%s)" % orphaned_instance.name)
+        if CONF.verbose:
+            print "ORPHANED INSTANCE (%s)" % orphaned_instance.name
+        else:
+            print orphaned_instance.name
 
 
 def clean_orphaned_instances(xenapi, orphaned_instances):
     """Clean orphaned instances."""
     for vm_ref, vm_rec, instance in orphaned_instances:
-        print("CLEANING INSTANCE (%s)" % instance.name)
+        if CONF.verbose:
+            print "CLEANING INSTANCE (%s)" % instance.name
 
         cleanup_instance(xenapi, instance, vm_ref, vm_rec)
 
 
 def main():
     """Main loop."""
-    config.parse_args(sys.argv)
-    args = CONF(args=sys.argv[1:], usage='%(prog)s [options] --command={' +
-            '|'.join(ALLOWED_COMMANDS) + '}')
-
-    command = CONF.command
-    if not command or command not in ALLOWED_COMMANDS:
+    args = CONF(args=sys.argv,
+                usage='%prog [options] [' + '|'.join(ALLOWED_COMMANDS) + ']')
+    if len(args) < 2:
         CONF.print_usage()
         sys.exit(1)
 
+    command = args[1]
+
     if CONF.zombie_instance_updated_at_window < CONF.resize_confirm_window:
         raise Exception("`zombie_instance_updated_at_window` has to be longer"
                 " than `resize_confirm_window`.")
 
-    # NOTE(blamar) This tool does not require DB access, so passing in the
-    # 'abstract' VirtAPI class is acceptable
-    xenapi = xenapi_driver.XenAPIDriver(virtapi.VirtAPI())
+    xenapi = xenapi_driver.XenAPIDriver()
 
     if command == "list-vdis":
-        print("Connected VDIs:\n")
+        if CONF.verbose:
+            print "Connected VDIs:\n"
         orphaned_vdi_uuids = find_orphaned_vdi_uuids(xenapi)
-        print("\nOrphaned VDIs:\n")
+        if CONF.verbose:
+            print "\nOrphaned VDIs:\n"
         list_orphaned_vdis(orphaned_vdi_uuids)
     elif command == "clean-vdis":
         orphaned_vdi_uuids = find_orphaned_vdi_uuids(xenapi)
@@ -308,7 +306,7 @@ def main():
     elif command == "test":
         doctest.testmod()
     else:
-        print("Unknown command '%s'" % command)
+        print "Unknown command '%s'" % command
         sys.exit(1)
 
 
